@@ -181,18 +181,6 @@ class Moderatable(RedditContentObject):
                 'how': 'yes' if as_made_by == 'mod' else as_made_by}
         return self.reddit_session.request_json(url, data=data)
 
-    @restrict_access(scope='modposts')
-    def mark_as_nsfw(self, unmark_nsfw=False):
-        """Mark object as Not Safe For Work.
-
-        :returns: The json response from the server.
-
-        """
-        url = self.reddit_session.config['unmarknsfw' if unmark_nsfw else
-                                         'marknsfw']
-        data = {'id': self.fullname}
-        return self.reddit_session.request_json(url, data=data)
-
     @restrict_access(scope='modposts')
     def remove(self, spam=False):
         """Remove object. This is the moderator version of delete.
@@ -222,14 +210,6 @@ class Moderatable(RedditContentObject):
         """
         return self.distinguish(as_made_by='no')
 
-    def unmark_as_nsfw(self):
-        """Mark object as Safe For Work.
-
-        :returns: The json response from the server.
-
-        """
-        return self.mark_as_nsfw(unmark_nsfw=True)
-
 
 class Editable(RedditContentObject):
 
@@ -878,6 +858,32 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         self._update_comments(new_comments)
         self._orphaned = {}
 
+    def mark_as_nsfw(self, unmark_nsfw=False):
+        """Mark as Not Safe For Work.
+
+        Requires that the currently authenticated user is the author of the
+        submission, has the modposts oauth scope or has user/password
+        authentication as a mod of the subreddit.
+
+        :returns: The json response from the server.
+
+        """
+        def mark_as_nsfw_helper(self):  # pylint: disable-msg=W0613
+            # It is necessary to have the 'self' argument as it's needed in
+            # restrict_access to determine what class the decorator is
+            # operating on.
+            url = self.reddit_session.config['unmarknsfw' if unmark_nsfw else
+                                             'marknsfw']
+            data = {'id': self.fullname}
+            return self.reddit_session.request_json(url, data=data)
+
+        is_author = (self.reddit_session.is_logged_in() and self.author ==
+                     self.reddit_session.user)
+        if is_author:
+            return mark_as_nsfw_helper(self)
+        else:
+            return restrict_access('modposts')(mark_as_nsfw_helper)(self)
+
     def replace_more_comments(self, limit=32, threshold=1):
         """Update the comment tree by replacing instances of MoreComments.
 
@@ -989,6 +995,14 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         data = {'id': self.fullname, 'state': True}
         return self.reddit_session.request_json(url, data=data)
 
+    def unmark_as_nsfw(self):
+        """Mark as Safe For Work.
+
+        :returns: The json response from the server.
+
+        """
+        return self.mark_as_nsfw(unmark_nsfw=True)
+
     @restrict_access(scope='modposts')
     def unset_contest_mode(self):
         """Unset 'Contest Mode' for the comments of this submission.
@@ -1135,7 +1149,7 @@ class Subreddit(Messageable, Refreshable):
         self.display_name = subreddit_name
         self._url = reddit_session.config['subreddit'] % subreddit_name
         # '' is the hot listing
-        listings = ['new/', '', 'top/', 'controversial/']
+        listings = ['new/', '', 'top/', 'controversial/', 'rising/']
         base = (reddit_session.config['subreddit'] % self.display_name)
         self._listing_urls = [base + x + '.json' for x in listings]
 
